@@ -561,6 +561,7 @@ void getch2_enable(void){
     setsigaction(SIGTSTP, stop_sighandler, SA_RESETHAND, false);
     setsigaction(SIGINT,  quit_request_sighandler, SA_RESETHAND, false);
     setsigaction(SIGQUIT, quit_request_sighandler, SA_RESETHAND, false);
+    setsigaction(SIGTERM, quit_request_sighandler, SA_RESETHAND, false);
     setsigaction(SIGTTIN, SIG_IGN, 0, true);
 
     do_activate_getch2();
@@ -577,6 +578,7 @@ void getch2_disable(void){
     setsigaction(SIGTSTP, SIG_DFL, 0, false);
     setsigaction(SIGINT,  SIG_DFL, 0, false);
     setsigaction(SIGQUIT, SIG_DFL, 0, false);
+    setsigaction(SIGTERM, SIG_DFL, 0, false);
     setsigaction(SIGTTIN, SIG_DFL, 0, false);
 
     do_deactivate_getch2();
